@@ -695,17 +695,33 @@ def _get_base_admin_dc_by_iadmin(iadmin):       # 类似装饰器模式, 通过I
             - .filter(wiki_id=`asd`).order_by(`-id`)[:3]
         """
         _tmp = None
-        orm_executor = True     # 使用orm过滤器
+        orm_executor = True  # 使用orm过滤器
+
+        _ajax_search_term = None  # 用来ajax过滤
+        _ajax_return_qs_ls = None  # 以便使用ajax方法返回的qs_ls
 
         def get_search_results(self, request, queryset, search_term):
             if not self.orm_executor:
                 ret = super().get_search_results(request, queryset, search_term)
                 return ret
 
+            # --- 根据ajax方法返回qs_ls
+            bd_ajax_return_qs_ls = '_ajax_return_qs_ls'
+            if hasattr(self, bd_ajax_return_qs_ls) and getattr(self, bd_ajax_return_qs_ls) is not None:
+                queryset = getattr(self, bd_ajax_return_qs_ls)
+                setattr(self, bd_ajax_return_qs_ls, None)
+                ret = (queryset, False)
+                return ret
+
+            # --- 根据orm语句进行过滤
             prefix = '~'  # 反向过滤~pk
 
             reg = re.compile(r'^\..*?[\)\]]$')  # 让.filter(xxx), .order_by(xxx)等orm语句可以执行
 
+            if hasattr(self, '_ajax_search_term') and getattr(self, '_ajax_search_term'):
+                search_term = self._ajax_search_term
+                self._ajax_search_term = None
+
             if search_term and reg.match(search_term):
                 print('search_term: ', search_term)
 
