@@ -174,7 +174,7 @@ class AutoWiki(APIView):
             md = get_base_model(v.queryset)
             meta = md._meta
 
-            url = f'/api/{meta.app_label}/{f}/'
+            url = f'/api/{app_name}/{f}/'
 
             output_to_file_and_prt('------------ 请求URL')
             output_to_file_and_prt(f"`{url}`")
